==> acomea.contact-0.1.tar.gz: acomea.contact-0.1/acomea/contact/cms/plugins.py <==
# -*- coding: utf-8 -*-
import base64
import json
import os
import re
import time

from django.utils.translation import ugettext as _
from django import forms
from django.utils.http import base36_to_int
from django.http import HttpResponse, HttpResponseRedirect
from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
from django.conf import settings

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from cms.plugins.text.widgets.tinymce_widget import TinyMCEEditor

from jmb.core.utils.functions import import_class
from jmb.core.utils.cmsutils import get_abs_url_from_slug
from jmb.core.middleware.force_response import ForceResponse

#from acomea.contact import models
from acomea.contact.models import (
    Group, Contact, Email, Phone, PhoneCategory
)
from acomea.contact.cms.models import (
    TraceRequestsSettings,
    PrivacyManagementSettings,
    ConfirmContactSettings
)
from acomea.contact.utils.generic import send_contact_confirm_email, is_new_contact
from acomea.contact.utils.tokens import contact_token_generator


###################################
## CMS PLUGINS                    #
###################################
class TraceRequestsPlugin(CMSPluginBase):
    model = TraceRequestsSettings
    name = _("Trace Requests Form")
    module = _("Contact")
    admin_preview = False

    def get_form(self, request, obj=None, **kwargs):
        form = super(TraceRequestsPlugin, self).get_form(request, obj, **kwargs)
        form.base_fields['thanks_text_message'].widget = TinyMCEEditor()
        return form

    def set_values_string(self, dict_contact):
        json_contact = json.dumps(dict_contact)
        enc_stringa = base64.b64encode(json_contact)
        return enc_stringa

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)
        success = None
        file_url = None
        if (
            request.method == "POST" and 'form_id' in request.POST and
            request.POST['form_id'] == ("form_%s" % str(instance.id))
        ):
            form = form_class(
                request.POST,
                mandatory_amc=instance.mandatory_amc,
                mandatory_amc_err_message=instance.mandatory_amc_err_message
            )

            if form.is_valid():
                contact = form.save()
                contact.groups.add(instance.contact_group)
                values_string = self.set_values_string(form.cleaned_data)
                internal_file = False
                file_url = None
                if instance.internal_file:
                    file_url = instance.internal_file.url
                    internal_file = True
                if instance.external_file_url:
                    file_url = instance.external_file_url
                    internal_file = False
                send_contact_confirm_email(
                    contact=contact,
                    email=form.cleaned_data.get('email'),
                    request=request,
                    template=settings.CONTACT_TRACEREQUESTS_EMAIL_TEMPLATE,
                    subject="Conferma contatto",
                    alternate_url=file_url,
                    internal_file=internal_file,
                    values_string=values_string,
                )
                # form non modale con tracking URL popolata ->
                # redirect su tracking URL dell'iframe padre (per pagine fatte con iframe)
                if not instance.is_modal and instance.success_tracking_url:
                    context.update({'redirect_parent': True})

                if instance.is_modal:
                    success = '1'
                form = form_class()

            else:
                if instance.is_modal:
                    success = '0'

            context.update({
                'instance': instance,
                'form' if instance.is_modal else 'form_nm': form,
                'additional_modal_css_dict': self._parse_additional_modal_css(instance),
                'success': success,
                'placeholder':placeholder
            })
            return context
        else:
            form = form_class()

        context.update({
            'instance': instance,
            'form' if instance.is_modal else 'form_nm' : form,
            'additional_modal_css_dict': self._parse_additional_modal_css(instance),
            'placeholder':placeholder
            })
        return context

    def _parse_additional_modal_css(self, instance):
        css_rules_list = instance.additional_modal_css_rules.split("|")
        if len(css_rules_list) == 0:
            return None
        parsed_rules_dict = {}
        for rule in css_rules_list:
            pattern = '[\n\r\t]'
            rule = re.sub(pattern, '', rule)
            try:
                if rule[0] == "{":
                    parsed_rules_dict['modal_div_rules'] = rule.replace("{", "").replace("}", "")
                else:
                    selector = rule.split("{")[0]
                    rule = rule.split("{")[1].replace("}", "")
                    if selector:
                        parsed_rules_dict[selector] = rule
            except IndexError:
                pass
        return parsed_rules_dict


plugin_pool.register_plugin(TraceRequestsPlugin)


class PrivacyManagementPlugin(CMSPluginBase):
    model = PrivacyManagementSettings
    name = _("Gestione Privacy")
    module = _("Contact")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        user = request.user
        self.render_template = "contact/cms_plugins/empty.html"
        success = None

        if user.is_anonymous() or not instance.status:
            return context

        if not user.is_active:
            return context
        try:
            profilo = user.profilo
            contact = user.contact
        except Exception, e:
            return context

        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)

        if request.method == "POST":
            privacy_management_form = form_class(request.POST, instance=contact, profilo=profilo)
            if privacy_management_form.is_valid():
                privacy_management_form.save()
        else:
            privacy_management_form = form_class(instance=contact, profilo=profilo)

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'privacy_management_form': privacy_management_form,
            'not_cliente': not profilo.is_cliente
        })
        return context
plugin_pool.register_plugin(PrivacyManagementPlugin)


class ConfirmContactPlugin(CMSPluginBase):
    model = ConfirmContactSettings
    name = _("Conferma contatto")
    module = _("Contact")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = "contact/cms_plugins/empty.html"
        contact = _check_confirm_url(request)

        # se parametri per check del token assenti da GET oppure il plugin e'
        # disabilitato, reindirizza su pagina insuccesso (default: home)
        if not contact or not instance.status:
            redirect_to = get_abs_url_from_slug(instance.unsuccess_slug)
            if redirect_to:
                raise ForceResponse(HttpResponseRedirect(redirect_to))
            else:
                raise ForceResponse(HttpResponseRedirect('/'))

        alternate_url = request.GET.get('alternate_url', None)
        encoded = request.GET.get('encoded', None)

        ###
        values = request.GET.get('values', None)
        if values:
            dec_values = base64.b64decode(values)
            dict_contact = json.loads(dec_values)
            if 'auth_trattamento_dati' in dict_contact:
                dict_contact['auth_trattamento_dati'] = True if dict_contact['auth_trattamento_dati'] == u"True" else False
            if 'auth_materiale_commerciale' in dict_contact:
                dict_contact['auth_materiale_commerciale'] = True if dict_contact['auth_materiale_commerciale'] == u"True" else False
            contact.bonifica = True
            if 'auth_trattamento_dati' in dict_contact:
                contact.auth_trattamento_dati = dict_contact['auth_trattamento_dati']
            if 'auth_materiale_commerciale' in dict_contact:
                contact.auth_materiale_commerciale = dict_contact['auth_materiale_commerciale']
            if 'phone' in dict_contact:
                phones = contact.phones.filter(phone=dict_contact['phone'])
                if not phones:
                    phone_category, created = PhoneCategory.objects.get_or_create(
                        name='cellulare'
                    )
                    phone = Phone.objects.create(
                        phone=dict_contact['phone'],
                        category=phone_category,
                        contact=contact
                    )
            if not contact.user:
                contact.__dict__.update(**dict_contact)
        contact.save()
        if alternate_url:
            if encoded == "1":
                alternate_url = base64.b64decode(alternate_url)
            raise ForceResponse(HttpResponseRedirect(alternate_url))
        self.render_template = instance.confirmation_done_template

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context
plugin_pool.register_plugin(ConfirmContactPlugin)


def _check_confirm_url(request):
    if (
        'cidb36' in request.GET and
        'token' in request.GET
    ):
        try:
            cid_int = base36_to_int(request.GET['cidb36'])
            contact = Contact.objects.get(id=cid_int)
            if contact_token_generator.check_token(
                contact,
                request.GET['token']
            ):
                return contact
            else:
                return False
        except (ValueError, Contact.DoesNotExist) as exc:
            # il contatto non esiste / errore
            return False
    return False

==> acomea.contact-0.2.tar.gz: acomea.contact-0.2/acomea/contact/cms/plugins.py <==
# -*- coding: utf-8 -*-
import base64
import json
import os
import re
import time

from django.conf import settings
from django.contrib import messages
from django.utils.translation import ugettext as _
from django.utils.http import base36_to_int
from django.http import HttpResponseRedirect

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from cms.plugins.text.widgets.tinymce_widget import TinyMCEEditor

from jmb.core.utils.functions import import_class
from jmb.core.utils.cmsutils import get_abs_url_from_slug
from jmb.core.middleware.force_response import ForceResponse

#from acomea.contact import models
from acomea.contact.cms.forms import AuthCommercialeForm
from acomea.contact.models import (
    Group, Contact, Email, Phone, PhoneCategory
)
from acomea.contact.cms.models import (
    TraceRequestsSettings,
    PrivacyManagementSettings,
    ConfirmContactSettings,
    AuthCommercialSettings
)
from acomea.contact.utils.generic import send_contact_confirm_email
from acomea.contact.utils.tokens import contact_token_generator
from acomea.contact.utils.mailer import send_invite_to_contact


###################################
## CMS PLUGINS                    #
###################################
class TraceRequestsPlugin(CMSPluginBase):
    model = TraceRequestsSettings
    name = _("Trace Requests Form")
    module = _("Contact")
    admin_preview = False
    form_field_choices = settings.CONTACT_CMSPLUGINS_DEFAULT_TRACEREQUESTS_FORM_CLASSES
    form_template_name_choices = settings.CONTACT_CMSPLUGINS_DEFAULT_TRACEREQUESTS_FORM_TEMPLATES
    exclude = ('slug_privacy',)

    def get_form(self, request, obj=None, **kwargs):
        form = super(TraceRequestsPlugin, self).get_form(request, obj, **kwargs)
        form.base_fields['thanks_text_message'].widget = TinyMCEEditor()
        form.base_fields['form'].choices = self.form_field_choices
        form.base_fields['form_template_name'].choices = self.form_template_name_choices
        return form

    def set_values_string(self, dict_contact):
        json_contact = json.dumps(dict_contact)
        enc_stringa = base64.b64encode(json_contact)
        return enc_stringa

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)
        success = None
        file_url = None
        if (
            request.method == "POST" and 'form_id' in request.POST and
            request.POST['form_id'] == ("form_%s" % str(instance.id))
        ):
            form = form_class(
                request.POST,
                mandatory_amc=instance.mandatory_amc,
                mandatory_amc_err_message=instance.mandatory_amc_err_message
            )

            if form.is_valid():
                contact, contact_created = form.save()
                contact.groups.add(instance.contact_group)  # signal "contact_group_signal" change "first_group" field, to use contact instace remember to reload
                values_string = self.set_values_string(form.cleaned_data)
                internal_file = False
                file_url = None
                if instance.internal_file:
                    file_url = instance.internal_file.url
                    internal_file = True
                if instance.external_file_url:
                    file_url = instance.external_file_url
                    internal_file = False

                if instance.event:
                    send_invite_to_contact(
                        contact, instance.event, test=False, is_trace_request=True, continue_if_not_created=True,
                        test_in_subject=False, check_can_create=False,
                    )
                    if not contact_created and contact.bonifica:
                        context.update({'email_found': True})

                else:
                    send_contact_confirm_email(
                        contact=contact,
                        email=form.cleaned_data.get('email'),
                        request=request,
                        template=settings.CONTACT_TRACEREQUESTS_EMAIL_TEMPLATE,
                        subject="Conferma contatto",
                        alternate_url=file_url,
                        internal_file=internal_file,
                        values_string=values_string,
                    )

                # form non modale con tracking URL popolata ->
                # redirect su tracking URL dell'iframe padre (per pagine fatte con iframe)
                if not instance.is_modal and instance.success_tracking_url:
                    context.update({'redirect_parent': True})

                if instance.is_modal:
                    success = '1'
                form = form_class()

            else:
                if instance.is_modal:
                    success = '0'

            context.update({
                'instance': instance,
                'form': form,
                'additional_modal_css_dict': self._parse_additional_modal_css(instance),
                'success': success,
                'placeholder':placeholder
            })
            return context
        else:
            form = form_class()

        context.update({
            'instance': instance,
            'form': form,
            'additional_modal_css_dict': self._parse_additional_modal_css(instance),
            'placeholder': placeholder
            })
        return context

    def _parse_additional_modal_css(self, instance):
        css_rules_list = instance.additional_modal_css_rules.split("|")
        if len(css_rules_list) == 0:
            return None
        parsed_rules_dict = {}
        for rule in css_rules_list:
            pattern = '[\n\r\t]'
            rule = re.sub(pattern, '', rule)
            try:
                if rule[0] == "{":
                    parsed_rules_dict['modal_div_rules'] = rule.replace("{", "").replace("}", "")
                else:
                    selector = rule.split("{")[0]
                    rule = rule.split("{")[1].replace("}", "")
                    if selector:
                        parsed_rules_dict[selector] = rule
            except IndexError:
                pass
        return parsed_rules_dict


plugin_pool.register_plugin(TraceRequestsPlugin)


class PresetTraceRequestsPlugin(TraceRequestsPlugin):

    model = TraceRequestsSettings
    name = _("Preset Trace Requests Form")
    module = _("Contact")
    admin_preview = False
    form_field_choices = settings.CONTACT_CMSPLUGINS_PRESET_TRACEREQUESTS_FORM_CLASSES
    form_template_name_choices = settings.CONTACT_CMSPLUGINS_PRESET_TRACEREQUESTS_FORM_TEMPLATES
    exclude = ()  

plugin_pool.register_plugin(PresetTraceRequestsPlugin)


class PrivacyManagementPlugin(CMSPluginBase):
    model = PrivacyManagementSettings
    name = _("Gestione Privacy")
    module = _("Contact")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        user = request.user
        self.render_template = "contact/cms_plugins/empty.html"
        success = None

        if user.is_anonymous() or not instance.status:
            return context

        if not user.is_active:
            return context
        try:
            profilo = user.profilo
            contact = user.contact
        except Exception, e:
            return context

        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)

        if request.method == "POST":
            privacy_management_form = form_class(request.POST, instance=contact, profilo=profilo)
            if privacy_management_form.is_valid():
                privacy_management_form.save()
        else:
            privacy_management_form = form_class(instance=contact, profilo=profilo)

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'privacy_management_form': privacy_management_form,
            'not_cliente': not profilo.is_cliente,
        })
        return context
plugin_pool.register_plugin(PrivacyManagementPlugin)


class ConfirmContactPlugin(CMSPluginBase):
    model = ConfirmContactSettings
    name = _("Conferma contatto")
    module = _("Contact")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = "contact/cms_plugins/empty.html"
        contact = _check_confirm_url(request)

        # se parametri per check del token assenti da GET oppure il plugin e'
        # disabilitato, reindirizza su pagina insuccesso (default: home)
        if not contact or not instance.status:
            redirect_to = get_abs_url_from_slug(instance.unsuccess_slug)
            if redirect_to:
                raise ForceResponse(HttpResponseRedirect(redirect_to))
            else:
                raise ForceResponse(HttpResponseRedirect('/'))

        alternate_url = request.GET.get('alternate_url', None)
        encoded = request.GET.get('encoded', None)

        ###
        values = request.GET.get('values', None)
        if values:
            dec_values = base64.b64decode(values)
            dict_contact = json.loads(dec_values)
            if 'auth_trattamento_dati' in dict_contact:
                dict_contact['auth_trattamento_dati'] = True if dict_contact['auth_trattamento_dati'] == u"True" else False
            if 'auth_materiale_commerciale' in dict_contact:
                dict_contact['auth_materiale_commerciale'] = True if dict_contact['auth_materiale_commerciale'] == u"True" else False
            contact.bonifica = True
            if 'auth_trattamento_dati' in dict_contact:
                contact.auth_trattamento_dati = dict_contact['auth_trattamento_dati']
            if 'auth_materiale_commerciale' in dict_contact:
                contact.auth_materiale_commerciale = dict_contact['auth_materiale_commerciale']
            if 'phone' in dict_contact:
                phones = contact.phones.filter(phone=dict_contact['phone'])
                if not phones:
                    phone_category, created = PhoneCategory.objects.get_or_create(
                        name='cellulare'
                    )
                    phone = Phone.objects.create(
                        phone=dict_contact['phone'],
                        category=phone_category,
                        contact=contact
                    )
            if not contact.user:
                contact.__dict__.update(**dict_contact)
        contact.save()
        if alternate_url:
            if encoded == "1":
                alternate_url = base64.b64decode(alternate_url)
            raise ForceResponse(HttpResponseRedirect(alternate_url))
        self.render_template = instance.confirmation_done_template

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context
plugin_pool.register_plugin(ConfirmContactPlugin)


def _check_confirm_url(request):
    if (
        'cidb36' in request.GET and
        'token' in request.GET
    ):
        try:
            cid_int = base36_to_int(request.GET['cidb36'])
            contact = Contact.objects.get(id=cid_int)
            if contact_token_generator.check_token(
                contact,
                request.GET['token']
            ):
                return contact
            else:
                return False
        except (ValueError, Contact.DoesNotExist) as exc:
            # il contatto non esiste / errore
            return False
    return False


class AuthCheckPlugin(CMSPluginBase):
    name = _("Verifica Privacy")
    module = _("Contact")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        user = request.user
        self.render_template = "bootstrap3/contact/cms_plugins/empty.html"

        if user.is_anonymous():
            return context

        if hasattr(user, 'contact') and user.contact.auth_materiale_commerciale is None:
            self.render_template = "bootstrap3/contact/cms_plugins/modal_auth_commerciale.html"
            context.update({
                'instance': instance,
                'placeholder': placeholder,
                'open_modal': True,
            })
        return context
plugin_pool.register_plugin(AuthCheckPlugin)


class AuthCommercialPlugin(CMSPluginBase):
    name = _("Gestione Auth Commerciale")
    model = AuthCommercialSettings
    module = _("Contact")
    admin_preview = False
    render_template = 'contact/cms_plugins/empty.html'

    def render(self, context, instance, placeholder):
        request = context['request']
        user = request.user

        if user.is_anonymous():
            return context

        if instance.status is False:
            return context

        try:
            contact = user.contact
        except Exception:
            return context

        if contact.auth_materiale_commerciale is not None:
            return context

        self.render_template = 'contact/cms_plugins/auth_commerciale_form.html'

        if (
            request.method == 'POST' and
            'auth_commerciale_{}'.format(instance.id) in request.POST
        ):
            auth_commerciale_form = AuthCommercialeForm(request.POST, instance=contact)
            if auth_commerciale_form.is_valid():
                auth_commerciale_form.save()
                self.render_template = "contact/cms_plugins/empty.html"

        else:
            auth_commerciale_form = AuthCommercialeForm(instance=contact)

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'auth_commerciale_form': auth_commerciale_form,
        })
        return context
plugin_pool.register_plugin(AuthCommercialPlugin)
